from setuptools import setup

setup(name='carrots',
      version='0.1.7',
      description='Library to build RabbitMQ architectures like you were playing with lego blocks',
      url='http://github.com/croccam/carrots',
      author='Croccam',
      author_email='antcarri@gmail.com',
      license='MIT',
      packages=['carrots'],
      zip_safe=False)